summaryrefslogtreecommitdiffstats
path: root/kspell2
diff options
context:
space:
mode:
Diffstat (limited to 'kspell2')
-rw-r--r--kspell2/backgroundchecker.h2
-rw-r--r--kspell2/backgroundengine.h2
-rw-r--r--kspell2/broker.cpp6
-rw-r--r--kspell2/client.h2
-rw-r--r--kspell2/dictionary.h2
-rw-r--r--kspell2/filter.cpp8
-rw-r--r--kspell2/filter.h2
-rw-r--r--kspell2/plugins/configure.in.bot4
-rw-r--r--kspell2/plugins/configure.in.in2
-rw-r--r--kspell2/plugins/ispell/correct.cpp4
-rw-r--r--kspell2/plugins/ispell/good.cpp10
-rw-r--r--kspell2/plugins/ispell/hash.cpp2
-rw-r--r--kspell2/plugins/ispell/ispell.h28
-rw-r--r--kspell2/plugins/ispell/ispell_checker.cpp8
-rw-r--r--kspell2/plugins/ispell/ispell_checker.h14
-rw-r--r--kspell2/plugins/ispell/lookup.cpp6
-rw-r--r--kspell2/plugins/ispell/makedent.cpp14
-rw-r--r--kspell2/plugins/ispell/msgs.h10
-rw-r--r--kspell2/plugins/ispell/tgood.cpp38
-rw-r--r--kspell2/settings.cpp8
-rw-r--r--kspell2/tests/backgroundtest.h2
-rw-r--r--kspell2/tests/test_dialog.cpp2
-rw-r--r--kspell2/tests/test_dialog.h2
-rw-r--r--kspell2/ui/configui.ui4
-rw-r--r--kspell2/ui/configwidget.cpp4
-rw-r--r--kspell2/ui/dialog.cpp32
-rw-r--r--kspell2/ui/dialog.h4
-rw-r--r--kspell2/ui/highlighter.cpp2
-rw-r--r--kspell2/ui/kspell2ui.ui40
29 files changed, 132 insertions, 132 deletions
diff --git a/kspell2/backgroundchecker.h b/kspell2/backgroundchecker.h
index e5418d7ec..9346b0c89 100644
--- a/kspell2/backgroundchecker.h
+++ b/kspell2/backgroundchecker.h
@@ -46,7 +46,7 @@ namespace KSpell2
* @author Zack Rusin <zack@kde.org>
* @short class used for spell checking in the background
*/
- class KDE_EXPORT BackgroundChecker : public QObject
+ class KDE_EXPORT BackgroundChecker : public TQObject
{
Q_OBJECT
public:
diff --git a/kspell2/backgroundengine.h b/kspell2/backgroundengine.h
index 9534e970c..d5bee8ca5 100644
--- a/kspell2/backgroundengine.h
+++ b/kspell2/backgroundengine.h
@@ -31,7 +31,7 @@ namespace KSpell2
class Filter;
class Broker;
class Dictionary;
- class BackgroundEngine : public QObject
+ class BackgroundEngine : public TQObject
{
Q_OBJECT
public:
diff --git a/kspell2/broker.cpp b/kspell2/broker.cpp
index 7f572bb01..b24f20beb 100644
--- a/kspell2/broker.cpp
+++ b/kspell2/broker.cpp
@@ -65,7 +65,7 @@ Broker *Broker::openBroker( KSharedConfig *config )
preventDeletion = config;
if ( s_brokers ) {
- Broker *broker = s_brokers->find( preventDeletion );
+ Broker *broker = s_brokers->tqfind( preventDeletion );
if ( broker )
return broker;
}
@@ -189,8 +189,8 @@ void Broker::loadPlugin( const TQString& pluginId )
kdDebug()<<"Loading plugin " << pluginId << endl;
Client *client = KParts::ComponentFactory::createInstanceFromQuery<Client>(
- TQString::fromLatin1( "KSpell/Client" ),
- TQString::fromLatin1( "[X-KDE-PluginInfo-Name]=='%1'" ).arg( pluginId ),
+ TQString::tqfromLatin1( "KSpell/Client" ),
+ TQString::tqfromLatin1( "[X-KDE-PluginInfo-Name]=='%1'" ).arg( pluginId ),
this, 0, TQStringList(), &error );
if ( client )
diff --git a/kspell2/client.h b/kspell2/client.h
index 86046e204..f06b760bf 100644
--- a/kspell2/client.h
+++ b/kspell2/client.h
@@ -38,7 +38,7 @@ namespace KSpell2
* I don't really feel like writting my own KLibFactory
* that would load anything else then TQObject derivatives.
*/
- class KDE_EXPORT Client : public QObject
+ class KDE_EXPORT Client : public TQObject
{
Q_OBJECT
public:
diff --git a/kspell2/dictionary.h b/kspell2/dictionary.h
index 31567ece9..9f4777f35 100644
--- a/kspell2/dictionary.h
+++ b/kspell2/dictionary.h
@@ -59,7 +59,7 @@ namespace KSpell2
TQStringList& suggestions ) =0;
/**
- * Stores user defined good replacement for the bad word.
+ * Stores user defined good tqreplacement for the bad word.
* @returns true on success
*/
virtual bool storeReplacement( const TQString& bad,
diff --git a/kspell2/filter.cpp b/kspell2/filter.cpp
index 1604bcae1..6b62481ad 100644
--- a/kspell2/filter.cpp
+++ b/kspell2/filter.cpp
@@ -202,7 +202,7 @@ int Filter::currentPosition() const
return m_currentPosition;
}
-void Filter::replace( const Word& w, const TQString& newWord)
+void Filter::tqreplace( const Word& w, const TQString& newWord)
{
int oldLen = w.word.length();
int newLen = newWord.length();
@@ -213,7 +213,7 @@ void Filter::replace( const Word& w, const TQString& newWord)
m_currentPosition += len;
}
}
- m_buffer = m_buffer.replace( w.start, oldLen, newWord );
+ m_buffer = m_buffer.tqreplace( w.start, oldLen, newWord );
}
TQString Filter::context() const
@@ -227,7 +227,7 @@ TQString Filter::context() const
TQString buffer = m_buffer;
Word word = wordAtPosition( m_currentPosition );
- buffer = buffer.replace( word.start, word.word.length(),
+ buffer = buffer.tqreplace( word.start, word.word.length(),
TQString( "<b>%1</b>" ).arg( word.word ) );
TQString context;
@@ -238,7 +238,7 @@ TQString Filter::context() const
context = TQString( "...%1..." )
.arg( buffer.mid( m_currentPosition - 20, len ) );
- context = context.replace( '\n', ' ' );
+ context = context.tqreplace( '\n', ' ' );
return context;
}
diff --git a/kspell2/filter.h b/kspell2/filter.h
index 5e4635493..e0f2ba3a0 100644
--- a/kspell2/filter.h
+++ b/kspell2/filter.h
@@ -95,7 +95,7 @@ namespace KSpell2
virtual void setCurrentPosition( int );
virtual int currentPosition() const;
- virtual void replace( const Word& w, const TQString& newWord );
+ virtual void tqreplace( const Word& w, const TQString& newWord );
/**
* Should return the sentence containing the current word
diff --git a/kspell2/plugins/configure.in.bot b/kspell2/plugins/configure.in.bot
index e47c874e0..d4e0e407c 100644
--- a/kspell2/plugins/configure.in.bot
+++ b/kspell2/plugins/configure.in.bot
@@ -1,13 +1,13 @@
if test -z "$LIBASPELL"; then
echo ""
- echo "Your libaspell is too old or not installed, I couldn't find aspell.h."
+ echo "Your libaspell is too old or not installed, I couldn't tqfind aspell.h."
echo "You must download aspell >= 0.50.2, see http://aspell.net"
echo "Spell-checking with libaspell will not be available, only with ispell dicts."
echo ""
fi
if test -z "$LIBHSPELL"; then
echo ""
-echo "The development package of Hspell is not installed, I couldn't find hspell.h."
+echo "The development package of Hspell is not installed, I couldn't tqfind hspell.h."
echo "Spell-checking Hebrew with libhspell will not be available."
echo "If you need it, install hspell >= 0.9 from sources"
echo "see http://www.ivrix.org.il/projects/spell-checker/"
diff --git a/kspell2/plugins/configure.in.in b/kspell2/plugins/configure.in.in
index 8aaf6de2c..16efb6b2f 100644
--- a/kspell2/plugins/configure.in.in
+++ b/kspell2/plugins/configure.in.in
@@ -8,7 +8,7 @@
KDE_CHECK_HEADER(aspell.h)
if test -z "$ac_cv_header_aspell_h"; then
echo ""
- echo "Your libaspell is too old or not installed, I couldn't find aspell.h."
+ echo "Your libaspell is too old or not installed, I couldn't tqfind aspell.h."
echo "You must download aspell >= 0.50.2, see http://aspell.net"
echo "Spell-checking with libaspell will not be available, only with ispell dicts."
echo ""
diff --git a/kspell2/plugins/ispell/correct.cpp b/kspell2/plugins/ispell/correct.cpp
index 65e98fa6d..7e52dff2f 100644
--- a/kspell2/plugins/ispell/correct.cpp
+++ b/kspell2/plugins/ispell/correct.cpp
@@ -789,9 +789,9 @@ ISpellChecker::save_root_cap (ichar_t *word, ichar_t *pattern,
#else /* NO_CAPITALIZATION_SUPPORT */
#define flagsareok(dent) \
((pfxent == NULL \
- || TSTMASKBIT (dent->mask, pfxent->flagbit)) \
+ || TSTMASKBIT (dent->tqmask, pfxent->flagbit)) \
&& (sufent == NULL \
- || TSTMASKBIT (dent->mask, sufent->flagbit)))
+ || TSTMASKBIT (dent->tqmask, sufent->flagbit)))
dent = firstdent;
if ((dent->flagfield & (CAPTYPEMASK | MOREVARIANTS)) == ALLCAPS)
diff --git a/kspell2/plugins/ispell/good.cpp b/kspell2/plugins/ispell/good.cpp
index 351106d99..1cd3c0dc0 100644
--- a/kspell2/plugins/ispell/good.cpp
+++ b/kspell2/plugins/ispell/good.cpp
@@ -145,7 +145,7 @@
*
* I've doctored the ispell code pretty extensively here. It is now
* warning-free on Win32. It also *works* on Win32 now, since I
- * replaced all the I/O calls with ANSI standard ones.
+ * tqreplaced all the I/O calls with ANSI standard ones.
*
* Revision 1.3 1998/12/28 23:11:30 eric
*
@@ -161,13 +161,13 @@
* of this is a hack.
*
* 1. added other/spell to the -I list in config/abi_defs
- * 2. replaced other/spell/Makefile with one which is more like
+ * 2. tqreplaced other/spell/Makefile with one which is more like
* our build system.
* 3. added other/spell to other/Makefile so that the build will now
* dive down and build the spell check library.
* 4. added the AbiSpell library to the Makefiles in wp/main
* 5. added a call to SpellCheckInit in wp/main/unix/UnixMain.cpp.
- * This call is a HACK and should be replaced with something
+ * This call is a HACK and should be tqreplaced with something
* proper later.
* 6. added code to fv_View.cpp as follows:
* whenever you double-click on a word, the spell checker
@@ -231,9 +231,9 @@ int good P ((ichar_t * word, int ignoreflagbits, int allhits,
*/
static int entryhasaffixes (struct dent *dent, struct success *hit)
{
- if (hit->prefix && !TSTMASKBIT (dent->mask, hit->prefix->flagbit))
+ if (hit->prefix && !TSTMASKBIT (dent->tqmask, hit->prefix->flagbit))
return 0;
- if (hit->suffix && !TSTMASKBIT (dent->mask, hit->suffix->flagbit))
+ if (hit->suffix && !TSTMASKBIT (dent->tqmask, hit->suffix->flagbit))
return 0;
return 1; /* Yes, these affixes are legal */
}
diff --git a/kspell2/plugins/ispell/hash.cpp b/kspell2/plugins/ispell/hash.cpp
index 03bd880bb..a072c080a 100644
--- a/kspell2/plugins/ispell/hash.cpp
+++ b/kspell2/plugins/ispell/hash.cpp
@@ -138,7 +138,7 @@
*
* I've doctored the ispell code pretty extensively here. It is now
* warning-free on Win32. It also *works* on Win32 now, since I
- * replaced all the I/O calls with ANSI standard ones.
+ * tqreplaced all the I/O calls with ANSI standard ones.
*
* Revision 1.2 1998/12/28 23:11:30 eric
*
diff --git a/kspell2/plugins/ispell/ispell_checker.cpp b/kspell2/plugins/ispell/ispell_checker.cpp
index 6b3d382af..2d96395dc 100644
--- a/kspell2/plugins/ispell/ispell_checker.cpp
+++ b/kspell2/plugins/ispell/ispell_checker.cpp
@@ -423,7 +423,7 @@ ISpellChecker::setDictionaryEncoding( const TQString& hashname, const char * enc
if (m_translate_in)
{
/* We still have to setup prefstringchar*/
- prefstringchar = findfiletype("utf8", 1, deftflag < 0 ? &deftflag
+ prefstringchar = tqfindfiletype("utf8", 1, deftflag < 0 ? &deftflag
: static_cast<int *>(NULL));
if (prefstringchar < 0)
@@ -432,7 +432,7 @@ ISpellChecker::setDictionaryEncoding( const TQString& hashname, const char * enc
for(int n1 = 1; n1 <= 15; n1++)
{
teststring = "latin" + n1;
- prefstringchar = findfiletype(teststring.c_str(), 1,
+ prefstringchar = tqfindfiletype(teststring.c_str(), 1,
deftflag < 0 ? &deftflag : static_cast<int *>(NULL));
if (prefstringchar >= 0)
break;
@@ -443,7 +443,7 @@ ISpellChecker::setDictionaryEncoding( const TQString& hashname, const char * enc
}
/* Test for UTF-8 first */
- prefstringchar = findfiletype("utf8", 1, deftflag < 0 ? &deftflag : static_cast<int *>(NULL));
+ prefstringchar = tqfindfiletype("utf8", 1, deftflag < 0 ? &deftflag : static_cast<int *>(NULL));
if (prefstringchar >= 0)
{
m_translate_in = TQTextCodec::codecForName("utf8");
@@ -459,7 +459,7 @@ ISpellChecker::setDictionaryEncoding( const TQString& hashname, const char * enc
for(int n1 = 1; n1 <= 15; n1++)
{
TQString teststring = TQString("latin%1").arg(n1);
- prefstringchar = findfiletype(teststring.latin1(), 1,
+ prefstringchar = tqfindfiletype(teststring.latin1(), 1,
deftflag < 0 ? &deftflag : static_cast<int *>(NULL));
if (prefstringchar >= 0)
{
diff --git a/kspell2/plugins/ispell/ispell_checker.h b/kspell2/plugins/ispell/ispell_checker.h
index 08783922a..52d8bfd41 100644
--- a/kspell2/plugins/ispell/ispell_checker.h
+++ b/kspell2/plugins/ispell/ispell_checker.h
@@ -107,12 +107,12 @@ private:
int strtoichar (ichar_t* out, char* in, int outlen, int canonical);
int ichartostr (char* out, ichar_t* in, int outlen, int canonical);
char * ichartosstr (ichar_t* in, int canonical);
- int findfiletype (const char * name, int searchnames, int * deformatter);
+ int tqfindfiletype (const char * name, int searchnames, int * deformatter);
long whatcap (ichar_t* word);
/*
- HACK: macros replaced with function implementations
- so we could do a side-effect-free check for unicode
+ HACK: macros tqreplaced with function implementations
+ so we could do a side-effect-free check for tqunicode
characters which aren't in hashheader
*/
char myupper(ichar_t c);
@@ -167,12 +167,12 @@ private:
struct flagptr * ind, int optflags, struct flagent * pfxent,
int ignoreflagbits, int allhits));
int expand_pre P ((char * croot, ichar_t * rootword,
- MASKTYPE mask[], int option, char * extra));
+ MASKTYPE tqmask[], int option, char * extra));
int pr_pre_expansion P ((char * croot, ichar_t * rootword,
- struct flagent * flent, MASKTYPE mask[], int option,
+ struct flagent * flent, MASKTYPE tqmask[], int option,
char * extra));
int expand_suf P ((char * croot, ichar_t * rootword,
- MASKTYPE mask[], int optflags, int option, char * extra));
+ MASKTYPE tqmask[], int optflags, int option, char * extra));
int pr_suf_expansion P ((char * croot, ichar_t * rootword,
struct flagent * flent, int option, char * extra));
void forcelc P ((ichar_t * dst, int len));
@@ -261,7 +261,7 @@ private:
/* ..(defined as those using legal affixes) */
/*
- * The following array contains a list of characters that should be tried
+ * The following array tqcontains a list of characters that should be tried
* in "missingletter." Note that lowercase characters are omitted.
*/
int m_Trynum; /* Size of "Try" array */
diff --git a/kspell2/plugins/ispell/lookup.cpp b/kspell2/plugins/ispell/lookup.cpp
index 6030f49d0..cf49641e6 100644
--- a/kspell2/plugins/ispell/lookup.cpp
+++ b/kspell2/plugins/ispell/lookup.cpp
@@ -193,7 +193,7 @@
*
* I've doctored the ispell code pretty extensively here. It is now
* warning-free on Win32. It also *works* on Win32 now, since I
- * replaced all the I/O calls with ANSI standard ones.
+ * tqreplaced all the I/O calls with ANSI standard ones.
*
* Revision 1.3 1998/12/28 23:11:30 eric
*
@@ -209,13 +209,13 @@
* of this is a hack.
*
* 1. added other/spell to the -I list in config/abi_defs
- * 2. replaced other/spell/Makefile with one which is more like
+ * 2. tqreplaced other/spell/Makefile with one which is more like
* our build system.
* 3. added other/spell to other/Makefile so that the build will now
* dive down and build the spell check library.
* 4. added the AbiSpell library to the Makefiles in wp/main
* 5. added a call to SpellCheckInit in wp/main/unix/UnixMain.cpp.
- * This call is a HACK and should be replaced with something
+ * This call is a HACK and should be tqreplaced with something
* proper later.
* 6. added code to fv_View.cpp as follows:
* whenever you double-click on a word, the spell checker
diff --git a/kspell2/plugins/ispell/msgs.h b/kspell2/plugins/ispell/msgs.h
index e3f30220c..11fd3e636 100644
--- a/kspell2/plugins/ispell/msgs.h
+++ b/kspell2/plugins/ispell/msgs.h
@@ -72,7 +72,7 @@
/*
* Messages header file.
*
- * This file contains all text strings that are written by any of the
+ * This file tqcontains all text strings that are written by any of the
* C programs in the ispell package. The strings are collected here so that
* you can have the option of translating them into your local language for
* the benefit of your users.
@@ -120,7 +120,7 @@
* The code resembles the ispell code as much as possible still.
*
* Revision 1.31 1994/12/27 23:08:57 geoff
- * Add a message to be issued if a word contains illegal characters.
+ * Add a message to be issued if a word tqcontains illegal characters.
*
* Revision 1.30 1994/10/25 05:46:40 geoff
* Improve a couple of error messages relating to affix flags.
@@ -167,7 +167,7 @@
" Warning: this language table may exceed the maximum total affix length\nof %d by up to %d bytes. You should either increase MAXAFFIXLEN in config.X\nor shorten your largest affix/strip string difference. (This is the\n", \
max, excess
#define BHASH_C_BAFF_2 \
- "difference between the affix length and the strip length in a given\nreplacement rule, or the affix length if there is no strip string\nin that rule.)\n"
+ "difference between the affix length and the strip length in a given\ntqreplacement rule, or the affix length if there is no strip string\nin that rule.)\n"
#define BHASH_C_OVERFLOW "Hash table overflowed by %d words\n"
#define BHASH_C_CANT_OPEN_DICT "Can't open dictionary\n"
#define BHASH_C_NO_SPACE "Couldn't allocate hash table\n"
@@ -181,7 +181,7 @@
*/
#define CORR_C_HELP_1 "Whenever a word is found that is not in the dictionary,\r\n"
#define CORR_C_HELP_2 "it is printed on the first line of the screen. If the dictionary\r\n"
-#define CORR_C_HELP_3 "contains any similar words, they are listed with a number\r\n"
+#define CORR_C_HELP_3 "tqcontains any similar words, they are listed with a number\r\n"
#define CORR_C_HELP_4 "next to each one. You have the option of replacing the word\r\n"
#define CORR_C_HELP_5 "completely, or choosing one of the suggested words.\r\n"
/* You may add HELP_6 through HELP_9 if your language needs more lines */
@@ -274,7 +274,7 @@
* The following strings are used in makedent.c:
*/
#define MAKEDENT_C_NO_WORD_SPACE "\r\nCouldn't allocate space for word '%s'\r\n"
-#define MAKEDENT_C_BAD_WORD_CHAR "\r\nWord '%s' contains illegal characters\r\n"
+#define MAKEDENT_C_BAD_WORD_CHAR "\r\nWord '%s' tqcontains illegal characters\r\n"
/*
* The following strings are used in parse.y:
diff --git a/kspell2/settings.cpp b/kspell2/settings.cpp
index 664ae24e0..c220520e6 100644
--- a/kspell2/settings.cpp
+++ b/kspell2/settings.cpp
@@ -75,7 +75,7 @@ KSharedConfig *Settings::sharedConfig() const
void Settings::setDefaultLanguage( const TQString& lang )
{
TQStringList cs = d->broker->languages();
- if ( cs.find( lang ) != cs.end() &&
+ if ( cs.tqfind( lang ) != cs.end() &&
d->defaultLanguage != lang ) {
d->defaultLanguage = lang;
readIgnoreList();
@@ -94,7 +94,7 @@ void Settings::setDefaultClient( const TQString& client )
//Different from setDefaultLanguage because
//the number of clients can't be even close
//as big as the number of languages
- if ( d->broker->clients().contains( client ) ) {
+ if ( d->broker->clients().tqcontains( client ) ) {
d->defaultClient = client;
d->modified = true;
d->broker->changed();
@@ -167,7 +167,7 @@ TQStringList Settings::currentIgnoreList() const
void Settings::addWordToIgnore( const TQString& word )
{
- if ( !d->ignore.contains( word ) ) {
+ if ( !d->ignore.tqcontains( word ) ) {
d->modified = true;
d->ignore.insert( word, true );
}
@@ -175,7 +175,7 @@ void Settings::addWordToIgnore( const TQString& word )
bool Settings::ignore( const TQString& word )
{
- return d->ignore.contains( word );
+ return d->ignore.tqcontains( word );
}
void Settings::readIgnoreList()
diff --git a/kspell2/tests/backgroundtest.h b/kspell2/tests/backgroundtest.h
index fcdf9db55..2f08e9ce0 100644
--- a/kspell2/tests/backgroundtest.h
+++ b/kspell2/tests/backgroundtest.h
@@ -26,7 +26,7 @@
#include "backgroundchecker.h"
-class BackgroundTest : public QObject
+class BackgroundTest : public TQObject
{
Q_OBJECT
public:
diff --git a/kspell2/tests/test_dialog.cpp b/kspell2/tests/test_dialog.cpp
index f0ee1ab3b..bc5d808a8 100644
--- a/kspell2/tests/test_dialog.cpp
+++ b/kspell2/tests/test_dialog.cpp
@@ -49,7 +49,7 @@ void TestDialog::check( const TQString& buffer )
void TestDialog::doneChecking( const TQString& buf )
{
kdDebug()<<"Done with :"<<buf<<endl;
- qApp->quit();
+ tqApp->quit();
}
int main( int argc, char** argv )
diff --git a/kspell2/tests/test_dialog.h b/kspell2/tests/test_dialog.h
index 5ef2dd189..e8a6cf970 100644
--- a/kspell2/tests/test_dialog.h
+++ b/kspell2/tests/test_dialog.h
@@ -26,7 +26,7 @@
#include <tqobject.h>
-class TestDialog : public QObject
+class TestDialog : public TQObject
{
Q_OBJECT
public:
diff --git a/kspell2/ui/configui.ui b/kspell2/ui/configui.ui
index bf645b9c9..9ab8f8e62 100644
--- a/kspell2/ui/configui.ui
+++ b/kspell2/ui/configui.ui
@@ -6,7 +6,7 @@
<property name="name">
<cstring>KSpell2ConfigUI</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>0</x>
<y>0</y>
@@ -105,7 +105,7 @@
<include location="global" impldecl="in implementation">keditlistbox.h</include>
<include location="global" impldecl="in implementation">kcombobox.h</include>
</includes>
-<layoutdefaults spacing="6" margin="11"/>
+<tqlayoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kcombobox.h</includehint>
<includehint>keditlistbox.h</includehint>
diff --git a/kspell2/ui/configwidget.cpp b/kspell2/ui/configwidget.cpp
index 6d98955ae..65db6dd9d 100644
--- a/kspell2/ui/configwidget.cpp
+++ b/kspell2/ui/configwidget.cpp
@@ -56,7 +56,7 @@ void ConfigWidget::init( Broker *broker )
d = new Private;
d->broker = broker;
- TQVBoxLayout *layout = new TQVBoxLayout( this, 0, 0, "KSpell2ConfigUILayout");
+ TQVBoxLayout *tqlayout = new TQVBoxLayout( this, 0, 0, "KSpell2ConfigUILayout");
d->ui = new KSpell2ConfigUI( this );
TQStringList langs = d->broker->languages();
@@ -73,7 +73,7 @@ void ConfigWidget::init( Broker *broker )
d->ui->m_bgSpellCB->hide();//hidden by default
connect( d->ui->m_ignoreListBox, TQT_SIGNAL(changed()), TQT_SLOT(slotChanged()) );
- layout->addWidget( d->ui );
+ tqlayout->addWidget( d->ui );
}
void KSpell2::ConfigWidget::save()
diff --git a/kspell2/ui/dialog.cpp b/kspell2/ui/dialog.cpp
index 93b81fd94..18641a986 100644
--- a/kspell2/ui/dialog.cpp
+++ b/kspell2/ui/dialog.cpp
@@ -53,7 +53,7 @@ public:
BackgroundChecker *checker;
Word currentWord;
- TQMap<TQString, TQString> replaceAllMap;
+ TQMap<TQString, TQString> tqreplaceAllMap;
};
Dialog::Dialog( BackgroundChecker *checker,
@@ -81,9 +81,9 @@ void Dialog::initConnections()
{
connect( d->ui->m_addBtn, TQT_SIGNAL(clicked()),
TQT_SLOT(slotAddWord()) );
- connect( d->ui->m_replaceBtn, TQT_SIGNAL(clicked()),
+ connect( d->ui->m_tqreplaceBtn, TQT_SIGNAL(clicked()),
TQT_SLOT(slotReplaceWord()) );
- connect( d->ui->m_replaceAllBtn, TQT_SIGNAL(clicked()),
+ connect( d->ui->m_tqreplaceAllBtn, TQT_SIGNAL(clicked()),
TQT_SLOT(slotReplaceAll()) );
connect( d->ui->m_skipBtn, TQT_SIGNAL(clicked()),
TQT_SLOT(slotSkip()) );
@@ -105,7 +105,7 @@ void Dialog::initConnections()
TQT_SLOT( slotReplaceWord() ) );
connect( this, TQT_SIGNAL(user1Clicked()), this, TQT_SLOT(slotFinished()) );
connect( this, TQT_SIGNAL(cancelClicked()),this, TQT_SLOT(slotCancel()) );
- connect( d->ui->m_replacement, TQT_SIGNAL(returnPressed()), this, TQT_SLOT(slotReplaceWord()) );
+ connect( d->ui->m_tqreplacement, TQT_SIGNAL(returnPressed()), this, TQT_SLOT(slotReplaceWord()) );
connect( d->ui->m_autoCorrect, TQT_SIGNAL(clicked()),
TQT_SLOT(slotAutocorrect()) );
// button use by kword/kpresenter
@@ -139,7 +139,7 @@ void Dialog::activeAutoCorrect( bool _active )
void Dialog::slotAutocorrect()
{
kdDebug()<<"void Dialog::slotAutocorrect()\n";
- emit autoCorrect(d->currentWord.word, d->ui->m_replacement->text() );
+ emit autoCorrect(d->currentWord.word, d->ui->m_tqreplacement->text() );
slotReplaceWord();
}
@@ -185,7 +185,7 @@ void Dialog::updateDialog( const TQString& word )
d->ui->m_unknownWord->setText( word );
d->ui->m_contextLabel->setText( d->checker->filter()->context() );
TQStringList suggs = d->checker->suggest( word );
- d->ui->m_replacement->setText( suggs.first() );
+ d->ui->m_tqreplacement->setText( suggs.first() );
fillSuggestions( suggs );
}
@@ -206,16 +206,16 @@ void Dialog::slotAddWord()
void Dialog::slotReplaceWord()
{
- emit replace( d->currentWord.word, d->currentWord.start,
- d->ui->m_replacement->text() );
- d->checker->filter()->replace( d->currentWord, d->ui->m_replacement->text() );
+ emit tqreplace( d->currentWord.word, d->currentWord.start,
+ d->ui->m_tqreplacement->text() );
+ d->checker->filter()->tqreplace( d->currentWord, d->ui->m_tqreplacement->text() );
d->checker->continueChecking();
}
void Dialog::slotReplaceAll()
{
- d->replaceAllMap.insert( d->currentWord.word,
- d->ui->m_replacement->text() );
+ d->tqreplaceAllMap.insert( d->currentWord.word,
+ d->ui->m_tqreplacement->text() );
slotReplaceWord();
}
@@ -227,13 +227,13 @@ void Dialog::slotSkip()
void Dialog::slotSkipAll()
{
//### do we want that or should we have a d->ignoreAll list?
- d->checker->broker()->settings()->addWordToIgnore( d->ui->m_replacement->text() );
+ d->checker->broker()->settings()->addWordToIgnore( d->ui->m_tqreplacement->text() );
d->checker->continueChecking();
}
void Dialog::slotSuggest()
{
- TQStringList suggs = d->checker->suggest( d->ui->m_replacement->text() );
+ TQStringList suggs = d->checker->suggest( d->ui->m_tqreplacement->text() );
fillSuggestions( suggs );
}
@@ -245,7 +245,7 @@ void Dialog::slotChangeLanguage( const TQString& lang )
void Dialog::slotSelectionChanged( TQListViewItem *item )
{
- d->ui->m_replacement->setText( item->text( 0 ) );
+ d->ui->m_tqreplacement->setText( item->text( 0 ) );
}
void Dialog::fillSuggestions( const TQStringList& suggs )
@@ -261,8 +261,8 @@ void Dialog::slotMisspelling(const TQString& word, int start )
{
kdDebug()<<"Dialog misspelling!!"<<endl;
d->currentWord = Word( word, start );
- if ( d->replaceAllMap.contains( word ) ) {
- d->ui->m_replacement->setText( d->replaceAllMap[ word ] );
+ if ( d->tqreplaceAllMap.tqcontains( word ) ) {
+ d->ui->m_tqreplacement->setText( d->tqreplaceAllMap[ word ] );
slotReplaceWord();
} else {
updateDialog( word );
diff --git a/kspell2/ui/dialog.h b/kspell2/ui/dialog.h
index 1da714c7c..cee715b48 100644
--- a/kspell2/ui/dialog.h
+++ b/kspell2/ui/dialog.h
@@ -49,12 +49,12 @@ namespace KSpell2
signals:
void done( const TQString& newBuffer );
void misspelling( const TQString& word, int start );
- void replace( const TQString& oldWord, int start,
+ void tqreplace( const TQString& oldWord, int start,
const TQString& newWord );
void stop();
void cancel();
- void autoCorrect( const TQString & currentWord, const TQString & replaceWord );
+ void autoCorrect( const TQString & currentWord, const TQString & tqreplaceWord );
private slots:
void slotMisspelling(const TQString& word, int start );
void slotDone();
diff --git a/kspell2/ui/highlighter.cpp b/kspell2/ui/highlighter.cpp
index 2d185462d..a3c33d7ae 100644
--- a/kspell2/ui/highlighter.cpp
+++ b/kspell2/ui/highlighter.cpp
@@ -110,7 +110,7 @@ TQString Highlighter::currentLanguage() const
void Highlighter::setCurrentLanguage( const TQString& lang )
{
- if ( !d->dictCache.find( lang ) ) {
+ if ( !d->dictCache.tqfind( lang ) ) {
Dictionary *dict = d->broker->dictionary( lang );
if ( dict ) {
d->dictCache.insert( lang, dict );
diff --git a/kspell2/ui/kspell2ui.ui b/kspell2/ui/kspell2ui.ui
index b8870f2f5..1822ef4b9 100644
--- a/kspell2/ui/kspell2ui.ui
+++ b/kspell2/ui/kspell2ui.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>KSpell2UI</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>0</x>
<y>0</y>
@@ -20,7 +20,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="minimumSize">
+ <property name="tqminimumSize">
<size>
<width>430</width>
<height>300</height>
@@ -40,7 +40,7 @@
<property name="whatsThis" stdset="0">
<string>&lt;qt&gt;&lt;p&gt;This word was considered to be an "unknown word" because it does not match any entry in the dictionary currently in use. It may also be a word in a foreign language.&lt;/p&gt;
&lt;p&gt;If the word is not misspelled, you may add it to the dictionary by clicking &lt;b&gt;Add to Dictionary&lt;/b&gt;. If you don't want to add the unknown word to the dictionary, but you want to leave it unchanged, click &lt;b&gt;Ignore&lt;/b&gt; or &lt;b&gt;Ignore All&lt;/b&gt;.&lt;/p&gt;
-&lt;p&gt;However, if the word is misspelled, you can try to find the correct replacement in the list below. If you cannot find a replacement there, you may type it in the text box below, and click &lt;b&gt;Replace&lt;/b&gt; or &lt;b&gt;Replace All&lt;/b&gt;.&lt;/p&gt;
+&lt;p&gt;However, if the word is misspelled, you can try to tqfind the correct tqreplacement in the list below. If you cannot tqfind a tqreplacement there, you may type it in the text box below, and click &lt;b&gt;Replace&lt;/b&gt; or &lt;b&gt;Replace All&lt;/b&gt;.&lt;/p&gt;
&lt;/qt&gt;</string>
</property>
</widget>
@@ -57,7 +57,7 @@
<property name="whatsThis" stdset="0">
<string>&lt;qt&gt;&lt;p&gt;This word was considered to be an "unknown word" because it does not match any entry in the dictionary currently in use. It may also be a word in a foreign language.&lt;/p&gt;
&lt;p&gt;If the word is not misspelled, you may add it to the dictionary by clicking &lt;b&gt;Add to Dictionary&lt;/b&gt;. If you don't want to add the unknown word to the dictionary, but you want to leave it unchanged, click &lt;b&gt;Ignore&lt;/b&gt; or &lt;b&gt;Ignore All&lt;/b&gt;.&lt;/p&gt;
-&lt;p&gt;However, if the word is misspelled, you can try to find the correct replacement in the list below. If you cannot find a replacement there, you may type it in the text box below, and click &lt;b&gt;Replace&lt;/b&gt; or &lt;b&gt;Replace All&lt;/b&gt;.&lt;/p&gt;
+&lt;p&gt;However, if the word is misspelled, you can try to tqfind the correct tqreplacement in the list below. If you cannot tqfind a tqreplacement there, you may type it in the text box below, and click &lt;b&gt;Replace&lt;/b&gt; or &lt;b&gt;Replace All&lt;/b&gt;.&lt;/p&gt;
&lt;/qt&gt;</string>
</property>
</widget>
@@ -87,7 +87,7 @@
<property name="text">
<string>... the &lt;b&gt;misspelled&lt;/b&gt; word shown in context ...</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>WordBreak|AlignCenter</set>
</property>
<property name="toolTip" stdset="0">
@@ -95,7 +95,7 @@
</property>
<property name="whatsThis" stdset="0">
<string>&lt;qt&gt;
-&lt;p&gt;Here you can see a text excerpt showing the unknown word in its context. If this information is not sufficient to choose the best replacement for the unknown word, you can click on the document you are proofing, read a larger part of the text and then return here to continue proofing.&lt;/p&gt;
+&lt;p&gt;Here you can see a text excerpt showing the unknown word in its context. If this information is not sufficient to choose the best tqreplacement for the unknown word, you can click on the document you are proofing, read a larger part of the text and then return here to continue proofing.&lt;/p&gt;
&lt;/qt&gt;</string>
</property>
</widget>
@@ -123,7 +123,7 @@ Click here if you consider that the unknown word is not misspelled and you want
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>74</width>
<height>20</height>
@@ -153,7 +153,7 @@ Click here if you consider that the unknown word is not misspelled and you want
</property>
<property name="whatsThis" stdset="0">
<string>&lt;qt&gt;
-&lt;p&gt;If the unknown word is misspelled, you should check if the correction for it is available and if it is, click on it. If none of the words in this list is a good replacement you may type the correct word in the edit box above.&lt;/p&gt;
+&lt;p&gt;If the unknown word is misspelled, you should check if the correction for it is available and if it is, click on it. If none of the words in this list is a good tqreplacement you may type the correct word in the edit box above.&lt;/p&gt;
&lt;p&gt;To correct this word click &lt;b&gt;Replace&lt;/b&gt; if you want to correct only this occurrence or &lt;b&gt;Replace All&lt;/b&gt; if you want to correct all occurrences.&lt;/p&gt;
&lt;/qt&gt;</string>
</property>
@@ -166,7 +166,7 @@ Click here if you consider that the unknown word is not misspelled and you want
<string>Replace &amp;with:</string>
</property>
<property name="buddy" stdset="0">
- <cstring>m_replacement</cstring>
+ <cstring>m_tqreplacement</cstring>
</property>
<property name="whatsThis" stdset="0">
<string>&lt;qt&gt;
@@ -177,7 +177,7 @@ Click here if you consider that the unknown word is not misspelled and you want
</widget>
<widget class="QLineEdit" row="2" column="2" rowspan="1" colspan="3">
<property name="name">
- <cstring>m_replacement</cstring>
+ <cstring>m_tqreplacement</cstring>
</property>
<property name="whatsThis" stdset="0">
<string>&lt;qt&gt;
@@ -206,7 +206,7 @@ Click here if you consider that the unknown word is not misspelled and you want
</widget>
<widget class="QLayoutWidget" row="2" column="5" rowspan="3" colspan="1">
<property name="name">
- <cstring>layout1</cstring>
+ <cstring>tqlayout1</cstring>
</property>
<vbox>
<property name="name">
@@ -222,27 +222,27 @@ Click here if you consider that the unknown word is not misspelled and you want
</widget>
<widget class="QPushButton">
<property name="name">
- <cstring>m_replaceBtn</cstring>
+ <cstring>m_tqreplaceBtn</cstring>
</property>
<property name="text">
<string>&amp;Replace</string>
</property>
<property name="whatsThis" stdset="0">
<string>&lt;qt&gt;
-&lt;p&gt;Click here to replace this occurrence of the unknown text with the text in the edit box above (to the left).&lt;/p&gt;
+&lt;p&gt;Click here to tqreplace this occurrence of the unknown text with the text in the edit box above (to the left).&lt;/p&gt;
&lt;/qt&gt;</string>
</property>
</widget>
<widget class="QPushButton">
<property name="name">
- <cstring>m_replaceAllBtn</cstring>
+ <cstring>m_tqreplaceAllBtn</cstring>
</property>
<property name="text">
<string>R&amp;eplace All</string>
</property>
<property name="whatsThis" stdset="0">
<string>&lt;qt&gt;
-&lt;p&gt;Click here to replace all occurrences of the unknown text with the text in the edit box above (to the left).&lt;/p&gt;
+&lt;p&gt;Click here to tqreplace all occurrences of the unknown text with the text in the edit box above (to the left).&lt;/p&gt;
&lt;/qt&gt;</string>
</property>
</widget>
@@ -298,7 +298,7 @@ Click here if you consider that the unknown word is not misspelled and you want
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -311,14 +311,14 @@ Click here if you consider that the unknown word is not misspelled and you want
</widget>
<tabstops>
<tabstop>m_addBtn</tabstop>
- <tabstop>m_replacement</tabstop>
+ <tabstop>m_tqreplacement</tabstop>
<tabstop>m_suggestBtn</tabstop>
- <tabstop>m_replaceBtn</tabstop>
- <tabstop>m_replaceAllBtn</tabstop>
+ <tabstop>m_tqreplaceBtn</tabstop>
+ <tabstop>m_tqreplaceAllBtn</tabstop>
<tabstop>m_skipBtn</tabstop>
<tabstop>m_skipAllBtn</tabstop>
<tabstop>m_suggestions</tabstop>
<tabstop>m_language</tabstop>
</tabstops>
-<layoutdefaults spacing="6" margin="11"/>
+<tqlayoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/kspell2/plugins/ispell/ispell.h b/kspell2/plugins/ispell/ispell.h
index 587defc07..01e1aa8a2 100644
--- a/kspell2/plugins/ispell/ispell.h
+++ b/kspell2/plugins/ispell/ispell.h
@@ -199,7 +199,7 @@
*
* I've doctored the ispell code pretty extensively here. It is now
* warning-free on Win32. It also *works* on Win32 now, since I
- * replaced all the I/O calls with ANSI standard ones.
+ * tqreplaced all the I/O calls with ANSI standard ones.
*
* Revision 1.1 1998/12/28 18:04:43 davet
* Spell checker code stripped from ispell. At this point, there are
@@ -268,7 +268,7 @@ extern "C" {
#endif
/*
** Number of mask bits (affix flags) supported. Must be 32, 64, 128, or
** 256. If MASKBITS is 32 or 64, there are really only 26 or 58 flags
** available, respectively. If it is 32, the flags are named with the
** 26 English uppercase letters; lowercase will be converted to uppercase.
@@ -290,7 +290,7 @@ extern "C" {
extern int gnMaskBits;
/*
-** C type to use for masks. This should be a type that the processor
+** C type to use for tqmasks. This should be a type that the processor
** accesses efficiently.
**
** MASKTYPE_WIDTH must correctly reflect the number of bits in a
@@ -401,11 +401,11 @@ extern int gnMaskBits;
#define MASKSIZE (gnMaskBits / MASKTYPE_WIDTH)
#ifdef lint
-extern int TSTMASKBIT P ((MASKTYPE * mask, int bit));
+extern int TSTMASKBIT P ((MASKTYPE * tqmask, int bit));
#else /* lint */
/* The following is really testing for MASKSIZE <= 1, but cpp can't do that */
-#define TSTMASKBIT(mask, bit) \
- ((mask)[(bit) / MASKTYPE_WIDTH] & \
+#define TSTMASKBIT(tqmask, bit) \
+ ((tqmask)[(bit) / MASKTYPE_WIDTH] & \
((MASKTYPE) 1 << ((bit) & (MASKTYPE_WIDTH - 1))))
#endif /* lint */
@@ -466,7 +466,7 @@ struct dent
{
struct dent * next;
char * word;
- MASKTYPE mask[2];
+ MASKTYPE tqmask[2];
#ifdef FULLMASKSET
char flags;
#endif
@@ -474,7 +474,7 @@ struct dent
/*
** Flags in the directory entry. If FULLMASKSET is undefined, these are
** stored in the highest bits of the last longword of the mask field. If
** FULLMASKSET is defined, they are stored in the extra "flags" field.
#ifndef NO_CAPITALIZATION_SUPPORT
**
@@ -498,14 +498,14 @@ struct dent
** entries for it, linked together by the "next" field. The initial
** entry for such words will be a dummy entry, primarily for use by code
** that ignores capitalization. The "word" field of this entry will
** again point to an all-uppercase copy of the word. The "mask" field
** will contain the logical OR of the mask fields of all variants.
** A header entry is indicated by a capitalization type of ALLCAPS,
** with the MOREVARIANTS bit set.
**
** The following entries will define the individual variants. Each
** entry except the last has the MOREVARIANTS flag set, and each
-** contains one of the following capitalization options:
+** tqcontains one of the following capitalization options:
**
** ALLCAPS The word must appear in all capitals.
** CAPITALIZED The word must be capitalized (e.g., London).
@@ -519,7 +519,7 @@ struct dent
** ANYCASE The word may appear in lowercase, capitalized,
** or all-capitals.
**
** The "mask" field for the entry contains only the affix flag bits that
** are legal for that capitalization. The "word" field will be null
** except for FOLLOWCASE entries, where it will point to the
** correctly-capitalized spelling of the root word.
@@ -532,7 +532,7 @@ struct dent
** that is illegal due to an affix.
**
** Finally, note that variations in the KEEP flag can cause a multiple-variant
-** entry as well. For example, if the personal dictionary contains "ALPHA",
+** entry as well. For example, if the personal dictionary tqcontains "ALPHA",
** (KEEP flag set) and the user adds "alpha" with the KEEP flag clear, a
** multiple-variant entry will be created so that "alpha" will be accepted
** but only "ALPHA" will actually be kept.
@@ -541,7 +541,7 @@ struct dent
#ifdef FULLMASKSET
#define flagfield flags
#else
-#define flagfield mask[1]
+#define flagfield tqmask[1]
#endif
#define USED ((MASKTYPE) 1 << (FLAGBASE + 0))
#define KEEP ((MASKTYPE) 1 << (FLAGBASE + 1))
@@ -268,7 +268,7 @@ extern "C" {
#endif
/*
-** Number of mask bits (affix flags) supported. Must be 32, 64, 128, or
+** Number of tqmask bits (affix flags) supported. Must be 32, 64, 128, or
** 256. If MASKBITS is 32 or 64, there are really only 26 or 58 flags
** available, respectively. If it is 32, the flags are named with the
@@ -474,7 +474,7 @@ struct dent
/*
** Flags in the directory entry. If FULLMASKSET is undefined, these are
-** stored in the highest bits of the last longword of the mask field. If
+** stored in the highest bits of the last longword of the tqmask field. If
** FULLMASKSET is defined, they are stored in the extra "flags" field.
#ifndef NO_CAPITALIZATION_SUPPORT
@@ -498,14 +498,14 @@ struct dent
** entry for such words will be a dummy entry, primarily for use by code
** that ignores capitalization. The "word" field of this entry will
-** again point to an all-uppercase copy of the word. The "mask" field
-** will contain the logical OR of the mask fields of all variants.
+** again point to an all-uppercase copy of the word. The "tqmask" field
+** will contain the logical OR of the tqmask fields of all variants.
** A header entry is indicated by a capitalization type of ALLCAPS,
** with the MOREVARIANTS bit set.
@@ -519,7 +519,7 @@ struct dent
** or all-capitals.
**
-** The "mask" field for the entry contains only the affix flag bits that
+** The "tqmask" field for the entry tqcontains only the affix flag bits that
** are legal for that capitalization. The "word" field will be null
** except for FOLLOWCASE entries, where it will point to the
diff --git a/kspell2/plugins/ispell/makedent.cpp b/kspell2/plugins/ispell/makedent.cpp
index 9c168dc17..c2d9a1909 100644
--- a/kspell2/plugins/ispell/makedent.cpp
+++ b/kspell2/plugins/ispell/makedent.cpp
@@ -162,13 +162,13 @@
*
* I've doctored the ispell code pretty extensively here. It is now
* warning-free on Win32. It also *works* on Win32 now, since I
* replaced all the I/O calls with ANSI standard ones.
*
* Revision 1.3 1998/12/29 14:55:33 eric
*
* I've doctored the ispell code pretty extensively here. It is now
* warning-free on Win32. It also *works* on Win32 now, since I
* replaced all the I/O calls with ANSI standard ones.
*
* Revision 1.2 1998/12/28 23:11:30 eric
*
@@ -361,7 +361,7 @@ int ISpellChecker::addvheader ( struct dent *dp)
** If 1 is returned, newp->word may have been be freed using myfree.
**
** Life is made much more difficult by the KEEP flag's possibilities. We
-** must ensure that a !KEEP word doesn't find its way into the personal
+** must ensure that a !KEEP word doesn't tqfind its way into the personal
** dictionary as a result of this routine's actions. However, a !KEEP
** word that has affixes must have come from the main dictionary, so it
** is acceptable to combine entries in that case (got that?).
@@ -370,7 +370,7 @@ int ISpellChecker::addvheader ( struct dent *dp)
** to figure out. Basically, we want to choose one of the following actions:
**
** (1) Add newp's affixes and KEEP flag to oldp, and discard newp.
-** (2) Add oldp's affixes and KEEP flag to newp, replace oldp with
+** (2) Add oldp's affixes and KEEP flag to newp, tqreplace oldp with
** newp, and discard newp.
#ifndef NO_CAPITALIZATION_SUPPORT
** (3) Insert newp as a new entry in the variants list. If there is
@@ -858,7 +858,7 @@ icharncmp (ichar_t *s1, ichar_t *s2, int n)
* \return
*/
int
-ISpellChecker::findfiletype (const char *name, int searchnames, int *deformatter)
+ISpellChecker::tqfindfiletype (const char *name, int searchnames, int *deformatter)
{
char * cp; /* Pointer into suffix list */
int cplen; /* Length of current suffix */
@@ -902,8 +902,8 @@ ISpellChecker::findfiletype (const char *name, int searchnames, int *deformatter
}
/*
- HACK: macros replaced with function implementations
- so we could do a side-effect-free check for unicode
+ HACK: macros tqreplaced with function implementations
+ so we could do a side-effect-free check for tqunicode
characters which aren't in hashheader
TODO: this is just a workaround to keep us from crashing.
@@ -162,13 +162,13 @@
* I've doctored the ispell code pretty extensively here. It is now
* warning-free on Win32. It also *works* on Win32 now, since I
- * replaced all the I/O calls with ANSI standard ones.
+ * tqreplaced all the I/O calls with ANSI standard ones.
*
* Revision 1.3 1998/12/29 14:55:33 eric
@@ -162,13 +162,13 @@
* I've doctored the ispell code pretty extensively here. It is now
* warning-free on Win32. It also *works* on Win32 now, since I
- * replaced all the I/O calls with ANSI standard ones.
+ * tqreplaced all the I/O calls with ANSI standard ones.
*
* Revision 1.2 1998/12/28 23:11:30 eric
diff --git a/kspell2/plugins/ispell/tgood.cpp b/kspell2/plugins/ispell/tgood.cpp
index 06fbc99ef..58c3efcfa 100644
--- a/kspell2/plugins/ispell/tgood.cpp
+++ b/kspell2/plugins/ispell/tgood.cpp
@@ -153,13 +153,13 @@
*
* I've doctored the ispell code pretty extensively here. It is now
* warning-free on Win32. It also *works* on Win32 now, since I
- * replaced all the I/O calls with ANSI standard ones.
+ * tqreplaced all the I/O calls with ANSI standard ones.
*
* Revision 1.4 1998/12/29 14:55:33 eric
*
* I've doctored the ispell code pretty extensively here. It is now
* warning-free on Win32. It also *works* on Win32 now, since I
- * replaced all the I/O calls with ANSI standard ones.
+ * tqreplaced all the I/O calls with ANSI standard ones.
*
* Revision 1.3 1998/12/28 23:11:30 eric
*
@@ -175,13 +175,13 @@
* of this is a hack.
*
* 1. added other/spell to the -I list in config/abi_defs
- * 2. replaced other/spell/Makefile with one which is more like
+ * 2. tqreplaced other/spell/Makefile with one which is more like
* our build system.
* 3. added other/spell to other/Makefile so that the build will now
* dive down and build the spell check library.
* 4. added the AbiSpell library to the Makefiles in wp/main
* 5. added a call to SpellCheckInit in wp/main/unix/UnixMain.cpp.
- * This call is a HACK and should be replaced with something
+ * This call is a HACK and should be tqreplaced with something
* proper later.
* 6. added code to fv_View.cpp as follows:
* whenever you double-click on a word, the spell checker
@@ -325,7 +325,7 @@ void ISpellChecker::pfx_list_chk (ichar_t *word, ichar_t *ucword, int len, int o
&& tlen + flent->stripl >= flent->numconds)
{
/*
- * The prefix matches. Remove it, replace it by the "strip"
+ * The prefix matches. Remove it, tqreplace it by the "strip"
* string (if any), and check the original conditions.
*/
if (flent->stripl)
@@ -367,7 +367,7 @@ void ISpellChecker::pfx_list_chk (ichar_t *word, ichar_t *ucword, int len, int o
}
}
else if ((dent = ispell_lookup (tword, 1)) != NULL
- && TSTMASKBIT (dent->mask, flent->flagbit))
+ && TSTMASKBIT (dent->tqmask, flent->flagbit))
{
if (m_numhits < MAX_HITS)
{
@@ -495,7 +495,7 @@ void ISpellChecker::suf_list_chk (ichar_t *word, ichar_t *ucword,
&& tlen + flent->stripl >= flent->numconds)
{
/*
- * The suffix matches. Remove it, replace it by the "strip"
+ * The suffix matches. Remove it, tqreplace it by the "strip"
* string (if any), and check the original conditions.
*/
icharcpy (tword, ucword);
@@ -556,9 +556,9 @@ void ISpellChecker::suf_list_chk (ichar_t *word, ichar_t *ucword,
}
}
else if ((dent = ispell_lookup (tword, 1)) != NULL
- && TSTMASKBIT (dent->mask, flent->flagbit)
+ && TSTMASKBIT (dent->tqmask, flent->flagbit)
&& ((optflags & FF_CROSSPRODUCT) == 0
- || TSTMASKBIT (dent->mask, pfxent->flagbit)))
+ || TSTMASKBIT (dent->tqmask, pfxent->flagbit)))
{
if (m_numhits < MAX_HITS)
{
@@ -588,13 +588,13 @@ void ISpellChecker::suf_list_chk (ichar_t *word, ichar_t *ucword,
*
* \param croot Char version of rootword
* \param rootword Root word to expand
* \param mask Mask bits to expand on
* \param option Option, see expandmode
* \param extra Extra info to add to line
*
* \return
*/
-int ISpellChecker::expand_pre (char *croot, ichar_t *rootword, MASKTYPE mask[],
+int ISpellChecker::expand_pre (char *croot, ichar_t *rootword, MASKTYPE tqmask[],
int option, char *extra)
{
int entcount; /* No. of entries to process */
@@ -606,9 +606,9 @@ int ISpellChecker::expand_pre (char *croot, ichar_t *rootword, MASKTYPE mask[],
entcount > 0;
flent++, entcount--)
{
- if (TSTMASKBIT (mask, flent->flagbit))
+ if (TSTMASKBIT (tqmask, flent->flagbit))
explength +=
- pr_pre_expansion (croot, rootword, flent, mask, option, extra);
+ pr_pre_expansion (croot, rootword, flent, tqmask, option, extra);
}
return explength;
}
@@ -619,14 +619,14 @@ int ISpellChecker::expand_pre (char *croot, ichar_t *rootword, MASKTYPE mask[],
* \param croot Char version of rootword
* \param rootword Root word to expand
* \param flent Current table entry
* \param mask Mask bits to expand on
* \param option Option, see expandmode
* \param extra Extra info to add to line
*
* \return
*/
int ISpellChecker::pr_pre_expansion ( char *croot, ichar_t *rootword,
- struct flagent *flent, MASKTYPE mask[], int option,
+ struct flagent *flent, MASKTYPE tqmask[], int option,
char *extra)
{
int cond; /* Current condition number */
@@ -706,7 +706,7 @@ int ISpellChecker::pr_pre_expansion ( char *croot, ichar_t *rootword,
printf (" %s%s", ichartosstr (tword, 1), extra);
if (flent->flagflags & FF_CROSSPRODUCT)
return tlen
- + expand_suf (croot, tword, mask, FF_CROSSPRODUCT, option, extra);
+ + expand_suf (croot, tword, tqmask, FF_CROSSPRODUCT, option, extra);
else
return tlen;
}
@@ -716,14 +716,14 @@ int ISpellChecker::pr_pre_expansion ( char *croot, ichar_t *rootword,
*
* \param croot Char version of rootword
* \param rootword Root word to expand
* \param mask Mask bits to expand on
* \param optflags Affix option flags
* \param option Option, see expandmode
* \param extra Extra info to add to line
*
* \return
*/
-int ISpellChecker::expand_suf (char *croot, ichar_t *rootword, MASKTYPE mask[],
+int ISpellChecker::expand_suf (char *croot, ichar_t *rootword, MASKTYPE tqmask[],
int optflags, int option, char *extra)
{
int entcount; /* No. of entries to process */
@@ -735,7 +735,7 @@ int ISpellChecker::expand_suf (char *croot, ichar_t *rootword, MASKTYPE mask[],
entcount > 0;
flent++, entcount--)
{
- if (TSTMASKBIT (mask, flent->flagbit))
+ if (TSTMASKBIT (tqmask, flent->flagbit))
{
if ((optflags & FF_CROSSPRODUCT) == 0
|| (flent->flagflags & FF_CROSSPRODUCT))
@@ -588,13 +588,13 @@ void ISpellChecker::suf_list_chk (ichar_t *word, ichar_t *ucword,
* \param croot Char version of rootword
* \param rootword Root word to expand
- * \param mask Mask bits to expand on
+ * \param tqmask Mask bits to expand on
* \param option Option, see expandmode
* \param extra Extra info to add to line
@@ -619,14 +619,14 @@ int ISpellChecker::expand_pre (char *croot, ichar_t *rootword, MASKTYPE mask[],
* \param rootword Root word to expand
* \param flent Current table entry
- * \param mask Mask bits to expand on
+ * \param tqmask Mask bits to expand on
* \param option Option, see expandmode
* \param extra Extra info to add to line
@@ -716,14 +716,14 @@ int ISpellChecker::pr_pre_expansion ( char *croot, ichar_t *rootword,
* \param croot Char version of rootword
* \param rootword Root word to expand
- * \param mask Mask bits to expand on
+ * \param tqmask Mask bits to expand on
* \param optflags Affix option flags
* \param option Option, see expandmode